==> xwidgetsbase-8.8.7.tar.gz: lib/XWidgets/XDD/XDropSearch_Dialog.dart <==
part of xwidgetbase;

class XDropSearch_Dialog<T> extends StatefulWidget {
  XDropSearch_Dialog({
    Key? key,
    required this.itemSelected,
    required this.liItems,
    required this.label,
    required this.onChanged_ItemOfDD,
    this.label_Color,
    this.background_Color = Colors.transparent,
    this.itemWidgetBuilder,
    this.clearBTN,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.al_SearchBox_Active,
    this.clearBTN_Active = true,
    this.contentPadding,
    this.dropdownBuilder,
    this.item_TextStyle,
    this.item_TextAlignment,
    this.label_Style,
    this.autoValidateMode = AutovalidateMode.disabled,
    this.clearBTN_IconSize = 16,
    this.clearBTN_Padding,
    this.clearBTN_IconColor,
    this.clearBTN_Constraints,
    this.al_BackGroundColor,
    this.al_Title,
    this.al_Title_Color,
    this.al_Title_Style,
    this.al_SearchBoxBorderANDtitle_Color,
    this.dropBTN,
    this.dropBTN_Padding,
    this.dropBTN_IconColor,
    this.dropBTN_IconSize = 16,
    this.dropBTN_Constraints,
    this.labelANDborder_Color,
    this.label_Behavior,
    this.propToShowInItems,
  }) : super(key: key);
  T? itemSelected;
  final List<T> liItems;
  final String? label;
  final ValueChanged? onChanged_ItemOfDD;
  final String Function(T)? itemAsString;
  final Color? background_Color;
  final Widget Function(BuildContext, T?)? dropdownBuilder;
  final EdgeInsetsGeometry? contentPadding;
  final TextStyle? label_Style;
  final Color? label_Color;
  final Color? labelANDborder_Color;
  final FloatingLabelBehavior? label_Behavior; //TODO da vedere il naming
  final bool clearBTN_Active;
  final Widget? clearBTN;
  final Color? clearBTN_IconColor;
  final double? clearBTN_IconSize;
  final BoxConstraints? clearBTN_Constraints;
  final EdgeInsetsGeometry? clearBTN_Padding;
  final Widget? dropBTN;
  final Color? dropBTN_IconColor;
  final double? dropBTN_IconSize;
  final BoxConstraints? dropBTN_Constraints;
  final EdgeInsetsGeometry? dropBTN_Padding;
  final String? al_Title;
  final TextStyle? al_Title_Style;
  final Color? al_Title_Color;
  final Color? al_BackGroundColor;
  final bool? al_SearchBox_Active;
  final Color? al_SearchBoxBorderANDtitle_Color;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final TextStyle? item_TextStyle;
  final Alignment? item_TextAlignment;

  final String? propToShowInItems;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;

  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDropSearch_Dialog<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        dropdownButtonProps: DropdownButtonProps(
          color: widget.background_Color,
          iconSize: widget.dropBTN_IconSize!,
          constraints: widget.dropBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
          padding: widget.dropBTN_Padding ?? EdgeInsets.all(8),
          icon: widget.dropBTN ?? Icon(Icons.arrow_downward_sharp, color: widget.dropBTN_IconColor ?? Colors.white, size: widget.dropBTN_IconSize),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
          contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
          hintText: "",
          floatingLabelBehavior: widget.label_Behavior ?? FloatingLabelBehavior.always,
          label: Text(widget.label ?? "", style: widget.label_Style ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500])),
          fillColor: widget.background_Color,
          focusColor: widget.focusColorOfDD,
          filled: true,
          labelStyle: widget.label_Style ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          hintStyle: XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          border: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          disabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          enabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
        )),
        // baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color)),
        popupProps: PopupProps.dialog(
          searchFieldProps: TextFieldProps(decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.al_SearchBoxBorderANDtitle_Color)),
          fit: FlexFit.loose,
          showSearchBox: widget.al_SearchBox_Active ?? true,
          title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.al_Title ?? "<No Title>", style: widget.al_Title_Style ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white)))]),
          dialogProps: DialogProps(backgroundColor: widget.al_BackGroundColor ?? Colors.grey[900]),
          itemBuilder: widget.itemWidgetBuilder != null
              ? widget.itemWidgetBuilder
              : ((context, item, isSelected) {
                  return Card(child: Container(height: 35, alignment: widget.item_TextAlignment ?? Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!], style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white))));
                }),
        ),
        // : PopupProps.menu(
        //     searchFieldProps: TextFieldProps(
        //       decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
        //     ),
        //     fit: FlexFit.loose,
        //     showSearchBox: widget.visible_SearchBox ?? true,
        //     title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: widget.labelStyle ?? XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
        //     itemBuilder: widget.itemWidgetBuilder != null
        //         ? widget.itemWidgetBuilder
        //         : ((context, item, isSelected) {
        //             return Card(child: Container(height: 35, alignment: widget.textAlignment_Item ?? Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!], textAlign: widget.textAlign_Item ?? TextAlign.center, style: widget.textStyle_Item ?? XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black))));
        //           })),
        items: widget.liItems,
        selectedItem: widget.itemSelected,
        clearButtonProps: ClearButtonProps(
          padding: widget.clearBTN_Padding ?? EdgeInsets.all(8),
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.clearBTN_IconColor ?? Colors.white, size: widget.clearBTN_IconSize),
          isVisible: widget.clearBTN_Active,
          constraints: widget.clearBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
        ),
        onChanged: (value) {
          widget.onChanged_ItemOfDD!(value);
        },
        itemAsString: widget.itemAsString == null
            ? (i) {
                if (widget.propToShowInItems == null) {
                  return (" " + i.toString());
                } else {
                  return (i as dynamic)[widget.propToShowInItems];
                }
              }
            : widget.itemAsString,
        dropdownBuilder: widget.dropdownBuilder);
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
    );
  }
}

==> xwidgetsbase-8.8.8.tar.gz: lib/XWidgets/XDD/XDropSearch_Dialog.dart <==
part of xwidgetbase;

class XDropSearch_Dialog<T> extends StatefulWidget {
  XDropSearch_Dialog({
    Key? key,
    required this.itemSelected,
    required this.liItems,
    required this.label,
    required this.onChanged_ItemOfDD,
    this.label_Color,
    this.background_Color = Colors.transparent,
    this.itemWidgetBuilder,
    this.clearBTN,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.al_SearchBox_Active,
    this.clearBTN_Active = true,
    this.contentPadding,
    this.dropdownBuilder,
    this.item_TextStyle,
    this.item_TextAlignment,
    this.label_Style,
    this.autoValidateMode = AutovalidateMode.disabled,
    this.clearBTN_IconSize = 16,
    this.clearBTN_Padding,
    this.clearBTN_IconColor,
    this.clearBTN_Constraints,
    this.al_BackGroundColor,
    this.al_Title,
    this.al_Title_Color,
    this.al_Title_Style,
    this.al_SearchBoxBorderANDtitle_Color,
    this.dropBTN,
    this.dropBTN_Padding,
    this.dropBTN_IconColor,
    this.dropBTN_IconSize = 16,
    this.dropBTN_Constraints,
    this.labelANDborder_Color,
    this.label_Behavior,
    this.propToShowInItems,
  }) : super(key: key);
  T? itemSelected;
  final List<T> liItems;
  final String? label;
  final ValueChanged? onChanged_ItemOfDD;
  final String Function(T)? itemAsString;
  final Color? background_Color;
  final Widget Function(BuildContext, T?)? dropdownBuilder;
  final EdgeInsetsGeometry? contentPadding;
  final TextStyle? label_Style;
  final Color? label_Color;
  final Color? labelANDborder_Color;
  final FloatingLabelBehavior? label_Behavior; //TODO da vedere il naming
  final bool clearBTN_Active;
  final Widget? clearBTN;
  final Color? clearBTN_IconColor;
  final double? clearBTN_IconSize;
  final BoxConstraints? clearBTN_Constraints;
  final EdgeInsetsGeometry? clearBTN_Padding;
  final Widget? dropBTN;
  final Color? dropBTN_IconColor;
  final double? dropBTN_IconSize;
  final BoxConstraints? dropBTN_Constraints;
  final EdgeInsetsGeometry? dropBTN_Padding;
  final String? al_Title;
  final TextStyle? al_Title_Style;
  final Color? al_Title_Color;
  final Color? al_BackGroundColor;
  final bool? al_SearchBox_Active;
  final Color? al_SearchBoxBorderANDtitle_Color;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final TextStyle? item_TextStyle;
  final Alignment? item_TextAlignment;

  final String? propToShowInItems;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;

  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDropSearch_Dialog<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        dropdownButtonProps: DropdownButtonProps(
          color: widget.background_Color,
          iconSize: widget.dropBTN_IconSize!,
          constraints: widget.dropBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
          padding: widget.dropBTN_Padding ?? EdgeInsets.all(8),
          icon: widget.dropBTN ?? Icon(Icons.arrow_downward_sharp, color: widget.dropBTN_IconColor ?? Colors.white, size: widget.dropBTN_IconSize),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
          contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
          hintText: "",
          floatingLabelBehavior: widget.label_Behavior ?? FloatingLabelBehavior.always,
          label: Text(widget.label ?? "", style: widget.label_Style ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500])),
          fillColor: widget.background_Color,
          focusColor: widget.focusColorOfDD,
          filled: true,
          labelStyle: widget.label_Style ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          hintStyle: XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          border: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          disabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          enabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
        )),
        // baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color)),
        popupProps: PopupProps.dialog(
          searchFieldProps: TextFieldProps(decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.al_SearchBoxBorderANDtitle_Color)),
          fit: FlexFit.loose,
          showSearchBox: widget.al_SearchBox_Active ?? true,
          title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.al_Title ?? "<No Title>", style: widget.al_Title_Style ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white)))]),
          dialogProps: DialogProps(backgroundColor: widget.al_BackGroundColor ?? Colors.grey[900]),
          itemBuilder: widget.itemWidgetBuilder != null
              ? widget.itemWidgetBuilder
              : ((context, item, isSelected) {
                  return Card(child: Container(height: 35, alignment: widget.item_TextAlignment ?? Alignment.center, child: Text(item as dynamic, style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white))));
                }),
        ),
        // : PopupProps.menu(
        //     searchFieldProps: TextFieldProps(
        //       decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
        //     ),
        //     fit: FlexFit.loose,
        //     showSearchBox: widget.visible_SearchBox ?? true,
        //     title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: widget.labelStyle ?? XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
        //     itemBuilder: widget.itemWidgetBuilder != null
        //         ? widget.itemWidgetBuilder
        //         : ((context, item, isSelected) {
        //             return Card(child: Container(height: 35, alignment: widget.textAlignment_Item ?? Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!], textAlign: widget.textAlign_Item ?? TextAlign.center, style: widget.textStyle_Item ?? XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black))));
        //           })),
        items: widget.liItems,
        selectedItem: widget.itemSelected,
        clearButtonProps: ClearButtonProps(
          padding: widget.clearBTN_Padding ?? EdgeInsets.all(8),
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.clearBTN_IconColor ?? Colors.white, size: widget.clearBTN_IconSize),
          isVisible: widget.clearBTN_Active,
          constraints: widget.clearBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
        ),
        onChanged: (value) {
          widget.onChanged_ItemOfDD!(value);
        },
        itemAsString: widget.itemAsString == null
            ? (i) {
                if (widget.propToShowInItems == null) {
                  return (" " + i.toString());
                } else {
                  return (i as dynamic)[widget.propToShowInItems];
                }
              }
            : widget.itemAsString,
        dropdownBuilder: widget.dropdownBuilder);
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
    );
  }
}
